basic_http_interceptor library

Support for doing something awesome.

More dartdocs go here.

Classes

InterceptorHeader
Header Manipulation
InterceptorHook
Hook, handle request, handle response
InterceptorLogger
Logger, request info, response info
MethodSwitchingClient
A client wrapper that dynamically routes requests between HTTP clients based on request type and content.

Functions

buildUrlString(String url, Map<String, dynamic>? parameters) String
Takes a string and appends parameters as query parameters of url.
interceptedClient({required List<InterceptorContract> interceptors, Map<String, String> proxy = const {}}) → InterceptedClient
get InterceptedClient